@@ -8,7 +8,7 @@ with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 """
 
-
+from gridtest.logger import bot
 import multiprocessing
 import os
 import sys
@@ -21,6 +21,7 @@ def getenv(variable_key, default=None, required=False, silent=True):
         Arguments:
 
          - variable_key (str) : the variable name
+         - default (str) : default value if variable_key does not exist
          - required (bool) : exit with error if not found
          - silent (bool) : Do not print debugging information
     """
